# This file was automatically generated by SWIG (http://www.swig.org).
# Version 3.0.12
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
if _swig_python_version_info >= (2, 7, 0):
    def swig_import_helper():
        import importlib
        pkg = __name__.rpartition('.')[0]
        mname = '.'.join((pkg, '_medparameter')).lstrip('.')
        try:
            return importlib.import_module(mname)
        except ImportError:
            return importlib.import_module('_medparameter')
    _medparameter = swig_import_helper()
    del swig_import_helper
elif _swig_python_version_info >= (2, 6, 0):
    def swig_import_helper():
        from os.path import dirname
        import imp
        fp = None
        try:
            fp, pathname, description = imp.find_module('_medparameter', [dirname(__file__)])
        except ImportError:
            import _medparameter
            return _medparameter
        try:
            _mod = imp.load_module('_medparameter', fp, pathname, description)
        finally:
            if fp is not None:
                fp.close()
        return _mod
    _medparameter = swig_import_helper()
    del swig_import_helper
else:
    import _medparameter
del _swig_python_version_info

try:
    _swig_property = property
except NameError:
    pass  # Python < 2.2 doesn't have 'property'.

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_setattr_nondynamic(self, class_type, name, value, static=1):
    if (name == "thisown"):
        return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'SwigPyObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name, None)
    if method:
        return method(self, value)
    if (not static):
        if _newclass:
            object.__setattr__(self, name, value)
        else:
            self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)


def _swig_setattr(self, class_type, name, value):
    return _swig_setattr_nondynamic(self, class_type, name, value, 0)


def _swig_getattr(self, class_type, name):
    if (name == "thisown"):
        return self.this.own()
    method = class_type.__swig_getmethods__.get(name, None)
    if method:
        return method(self)
    raise AttributeError("'%s' object has no attribute '%s'" % (class_type.__name__, name))


def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)

try:
    _object = object
    _newclass = 1
except __builtin__.Exception:
    class _object:
        pass
    _newclass = 0

class SwigPyIterator_medparameter_module(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, SwigPyIterator_medparameter_module, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, SwigPyIterator_medparameter_module, name)

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _medparameter.delete_SwigPyIterator_medparameter_module
    __del__ = lambda self: None

    def value(self):
        return _medparameter.SwigPyIterator_medparameter_module_value(self)

    def incr(self, n=1):
        return _medparameter.SwigPyIterator_medparameter_module_incr(self, n)

    def decr(self, n=1):
        return _medparameter.SwigPyIterator_medparameter_module_decr(self, n)

    def distance(self, x):
        return _medparameter.SwigPyIterator_medparameter_module_distance(self, x)

    def equal(self, x):
        return _medparameter.SwigPyIterator_medparameter_module_equal(self, x)

    def copy(self):
        return _medparameter.SwigPyIterator_medparameter_module_copy(self)

    def next(self):
        return _medparameter.SwigPyIterator_medparameter_module_next(self)

    def __next__(self):
        return _medparameter.SwigPyIterator_medparameter_module___next__(self)

    def previous(self):
        return _medparameter.SwigPyIterator_medparameter_module_previous(self)

    def advance(self, n):
        return _medparameter.SwigPyIterator_medparameter_module_advance(self, n)

    def __eq__(self, x):
        return _medparameter.SwigPyIterator_medparameter_module___eq__(self, x)

    def __ne__(self, x):
        return _medparameter.SwigPyIterator_medparameter_module___ne__(self, x)

    def __iadd__(self, n):
        return _medparameter.SwigPyIterator_medparameter_module___iadd__(self, n)

    def __isub__(self, n):
        return _medparameter.SwigPyIterator_medparameter_module___isub__(self, n)

    def __add__(self, n):
        return _medparameter.SwigPyIterator_medparameter_module___add__(self, n)

    def __sub__(self, *args):
        return _medparameter.SwigPyIterator_medparameter_module___sub__(self, *args)
    def __iter__(self): return self
    def __iter__(self):
        return self
SwigPyIterator_medparameter_module_swigregister = _medparameter.SwigPyIterator_medparameter_module_swigregister
SwigPyIterator_medparameter_module_swigregister(SwigPyIterator_medparameter_module)

ABSOLUTE_H5IPUBLIC_H = _medparameter.ABSOLUTE_H5IPUBLIC_H
ABSOLUTE_H5PUBLIC_H = _medparameter.ABSOLUTE_H5PUBLIC_H
HAVE_CC_C99 = _medparameter.HAVE_CC_C99
HAVE_CUSERID = _medparameter.HAVE_CUSERID
HAVE_DLFCN_H = _medparameter.HAVE_DLFCN_H
HAVE_FTIME = _medparameter.HAVE_FTIME
HAVE_GETEUID = _medparameter.HAVE_GETEUID
HAVE_GETPWUID = _medparameter.HAVE_GETPWUID
HAVE_GETTIMEOFDAY = _medparameter.HAVE_GETTIMEOFDAY
HAVE_H5IPUBLIC_H = _medparameter.HAVE_H5IPUBLIC_H
HAVE_H5PUBLIC_H = _medparameter.HAVE_H5PUBLIC_H
HAVE_INTTYPES_H = _medparameter.HAVE_INTTYPES_H
HAVE_LIBHDF5 = _medparameter.HAVE_LIBHDF5
HAVE_MALLOC_H = _medparameter.HAVE_MALLOC_H
HAVE_MEMORY_H = _medparameter.HAVE_MEMORY_H
HAVE_PWD_H = _medparameter.HAVE_PWD_H
HAVE_PYTHON = _medparameter.HAVE_PYTHON
HAVE_STDBOOL_H = _medparameter.HAVE_STDBOOL_H
HAVE_STDINT_H = _medparameter.HAVE_STDINT_H
HAVE_STDLIB_H = _medparameter.HAVE_STDLIB_H
HAVE_STRINGS_H = _medparameter.HAVE_STRINGS_H
HAVE_STRING_H = _medparameter.HAVE_STRING_H
HAVE_SYS_STAT_H = _medparameter.HAVE_SYS_STAT_H
HAVE_SYS_TIMEB_H = _medparameter.HAVE_SYS_TIMEB_H
HAVE_SYS_TIME_H = _medparameter.HAVE_SYS_TIME_H
HAVE_SYS_TYPES_H = _medparameter.HAVE_SYS_TYPES_H
HAVE_UNISTD_H = _medparameter.HAVE_UNISTD_H
HAVE__BOOL = _medparameter.HAVE__BOOL
LT_OBJDIR = _medparameter.LT_OBJDIR
MED_API_23 = _medparameter.MED_API_23
MED_CHECK_23FORMAT = _medparameter.MED_CHECK_23FORMAT
MED_HAVE_FORTRAN = _medparameter.MED_HAVE_FORTRAN
MED_HAVE_PYTHON = _medparameter.MED_HAVE_PYTHON
MESGERR = _medparameter.MESGERR
PACKAGE = _medparameter.PACKAGE
PACKAGE_BUGREPORT = _medparameter.PACKAGE_BUGREPORT
PACKAGE_NAME = _medparameter.PACKAGE_NAME
PACKAGE_STRING = _medparameter.PACKAGE_STRING
PACKAGE_TARNAME = _medparameter.PACKAGE_TARNAME
PACKAGE_URL = _medparameter.PACKAGE_URL
PACKAGE_VERSION = _medparameter.PACKAGE_VERSION
SIZEOF_FORTRAN_INTEGER = _medparameter.SIZEOF_FORTRAN_INTEGER
SIZEOF_FORTRAN_INTEGERp8 = _medparameter.SIZEOF_FORTRAN_INTEGERp8
SIZEOF_HID_T = _medparameter.SIZEOF_HID_T
SIZEOF_INT = _medparameter.SIZEOF_INT
SIZEOF_LONG = _medparameter.SIZEOF_LONG
SIZEOF_LONG_LONG = _medparameter.SIZEOF_LONG_LONG
STDC_HEADERS = _medparameter.STDC_HEADERS
TIME_WITH_SYS_TIME = _medparameter.TIME_WITH_SYS_TIME
VERSION = _medparameter.VERSION
HDF_VERSION_MAJOR_REF = _medparameter.HDF_VERSION_MAJOR_REF
HDF_VERSION_MINOR_REF = _medparameter.HDF_VERSION_MINOR_REF
HDF_VERSION_RELEASE_REF = _medparameter.HDF_VERSION_RELEASE_REF
HDF_VERSION_NUM_REF = _medparameter.HDF_VERSION_NUM_REF
H5F_LIBVER_18 = _medparameter.H5F_LIBVER_18
MED_MAJOR_NUM = _medparameter.MED_MAJOR_NUM
MED_MINOR_NUM = _medparameter.MED_MINOR_NUM
MED_RELEASE_NUM = _medparameter.MED_RELEASE_NUM
MED_3_LATEST_MINOR = _medparameter.MED_3_LATEST_MINOR
MED_4_LATEST_MINOR = _medparameter.MED_4_LATEST_MINOR
MED_NUM_MAJEUR = _medparameter.MED_NUM_MAJEUR
MED_NUM_MINEUR = _medparameter.MED_NUM_MINEUR
MED_NUM_RELEASE = _medparameter.MED_NUM_RELEASE
MED_VERSION_STR = _medparameter.MED_VERSION_STR
MED_MAX_PARA = _medparameter.MED_MAX_PARA
MED_COMMENT_SIZE = _medparameter.MED_COMMENT_SIZE
MED_IDENT_SIZE = _medparameter.MED_IDENT_SIZE
MED_NAME_SIZE = _medparameter.MED_NAME_SIZE
MED_SNAME_SIZE = _medparameter.MED_SNAME_SIZE
MED_LNAME_SIZE = _medparameter.MED_LNAME_SIZE
MED_SNAME_BLANK = _medparameter.MED_SNAME_BLANK
MED_NAME_BLANK = _medparameter.MED_NAME_BLANK
MED_PATHNAME_SIZE = _medparameter.MED_PATHNAME_SIZE
MED_MAX_CHFID_PATH = _medparameter.MED_MAX_CHFID_PATH
MED_FULL_INTERLACE = _medparameter.MED_FULL_INTERLACE
MED_NO_INTERLACE = _medparameter.MED_NO_INTERLACE
MED_UNDEF_INTERLACE = _medparameter.MED_UNDEF_INTERLACE
MED_UNDEF_STMODE = _medparameter.MED_UNDEF_STMODE
MED_GLOBAL_STMODE = _medparameter.MED_GLOBAL_STMODE
MED_COMPACT_STMODE = _medparameter.MED_COMPACT_STMODE
MED_GLOBAL_PFLMODE = _medparameter.MED_GLOBAL_PFLMODE
MED_COMPACT_PFLMODE = _medparameter.MED_COMPACT_PFLMODE
MED_UNDEF_PFLMODE = _medparameter.MED_UNDEF_PFLMODE
MED_ACC_RDONLY = _medparameter.MED_ACC_RDONLY
MED_ACC_RDWR = _medparameter.MED_ACC_RDWR
MED_ACC_RDEXT = _medparameter.MED_ACC_RDEXT
MED_ACC_CREAT = _medparameter.MED_ACC_CREAT
MED_ACC_UNDEF = _medparameter.MED_ACC_UNDEF
MED_UNSTRUCTURED_MESH = _medparameter.MED_UNSTRUCTURED_MESH
MED_STRUCTURED_MESH = _medparameter.MED_STRUCTURED_MESH
MED_UNDEF_MESH_TYPE = _medparameter.MED_UNDEF_MESH_TYPE
MED_CARTESIAN_GRID = _medparameter.MED_CARTESIAN_GRID
MED_POLAR_GRID = _medparameter.MED_POLAR_GRID
MED_CURVILINEAR_GRID = _medparameter.MED_CURVILINEAR_GRID
MED_UNDEF_GRID_TYPE = _medparameter.MED_UNDEF_GRID_TYPE
MED_CELL = _medparameter.MED_CELL
MED_DESCENDING_FACE = _medparameter.MED_DESCENDING_FACE
MED_DESCENDING_EDGE = _medparameter.MED_DESCENDING_EDGE
MED_NODE = _medparameter.MED_NODE
MED_NODE_ELEMENT = _medparameter.MED_NODE_ELEMENT
MED_STRUCT_ELEMENT = _medparameter.MED_STRUCT_ELEMENT
MED_ALL_ENTITY_TYPE = _medparameter.MED_ALL_ENTITY_TYPE
MED_UNDEF_ENTITY_TYPE = _medparameter.MED_UNDEF_ENTITY_TYPE
MED_N_ENTITY_TYPES = _medparameter.MED_N_ENTITY_TYPES
MED_COORDINATE = _medparameter.MED_COORDINATE
MED_CONNECTIVITY = _medparameter.MED_CONNECTIVITY
MED_NAME = _medparameter.MED_NAME
MED_NUMBER = _medparameter.MED_NUMBER
MED_FAMILY_NUMBER = _medparameter.MED_FAMILY_NUMBER
MED_COORDINATE_AXIS1 = _medparameter.MED_COORDINATE_AXIS1
MED_COORDINATE_AXIS2 = _medparameter.MED_COORDINATE_AXIS2
MED_COORDINATE_AXIS3 = _medparameter.MED_COORDINATE_AXIS3
MED_INDEX_FACE = _medparameter.MED_INDEX_FACE
MED_INDEX_NODE = _medparameter.MED_INDEX_NODE
MED_GLOBAL_NUMBER = _medparameter.MED_GLOBAL_NUMBER
MED_VARIABLE_ATTRIBUTE = _medparameter.MED_VARIABLE_ATTRIBUTE
MED_COORDINATE_TRSF = _medparameter.MED_COORDINATE_TRSF
MED_UNDEF_DATATYPE = _medparameter.MED_UNDEF_DATATYPE
MED_INTERNAL_FLOAT32 = _medparameter.MED_INTERNAL_FLOAT32
MED_INTERNAL_FLOAT64 = _medparameter.MED_INTERNAL_FLOAT64
MED_INTERNAL_INT32 = _medparameter.MED_INTERNAL_INT32
MED_INTERNAL_INT64 = _medparameter.MED_INTERNAL_INT64
MED_INTERNAL_INT = _medparameter.MED_INTERNAL_INT
MED_INTERNAL_NAME = _medparameter.MED_INTERNAL_NAME
MED_INTERNAL_SNAME = _medparameter.MED_INTERNAL_SNAME
MED_INTERNAL_LNAME = _medparameter.MED_INTERNAL_LNAME
MED_INTERNAL_IDENT = _medparameter.MED_INTERNAL_IDENT
MED_INTERNAL_CHAR = _medparameter.MED_INTERNAL_CHAR
MED_INTERNAL_UNDEF = _medparameter.MED_INTERNAL_UNDEF
MED_DOUBLE = _medparameter.MED_DOUBLE
MED_FLOAT64 = _medparameter.MED_FLOAT64
MED_FLOAT32 = _medparameter.MED_FLOAT32
MED_INT32 = _medparameter.MED_INT32
MED_INT64 = _medparameter.MED_INT64
MED_INT = _medparameter.MED_INT
MED_ATT_FLOAT64 = _medparameter.MED_ATT_FLOAT64
MED_ATT_INT = _medparameter.MED_ATT_INT
MED_ATT_NAME = _medparameter.MED_ATT_NAME
MED_ATT_UNDEF = _medparameter.MED_ATT_UNDEF
MED_MESH = _medparameter.MED_MESH
MED_FIELD = _medparameter.MED_FIELD
MED_LIBRARY = _medparameter.MED_LIBRARY
MED_FILE = _medparameter.MED_FILE
MED_MESH_SUPPORT = _medparameter.MED_MESH_SUPPORT
MED_ELSTRUCT = _medparameter.MED_ELSTRUCT
MED_FAMILY = _medparameter.MED_FAMILY
MED_EQUIVALENCE = _medparameter.MED_EQUIVALENCE
MED_GROUP = _medparameter.MED_GROUP
MED_JOINT = _medparameter.MED_JOINT
MED_LOCALIZATION = _medparameter.MED_LOCALIZATION
MED_PROFILE = _medparameter.MED_PROFILE
MED_FILTER = _medparameter.MED_FILTER
MED_INTERPOLATION = _medparameter.MED_INTERPOLATION
MED_NUMERICAL_DATA = _medparameter.MED_NUMERICAL_DATA
MED_LINK = _medparameter.MED_LINK
MED_CLASS_UNDEF = _medparameter.MED_CLASS_UNDEF
MED_CLASS_ALL = _medparameter.MED_CLASS_ALL
MED_POINT1 = _medparameter.MED_POINT1
MED_SEG2 = _medparameter.MED_SEG2
MED_SEG3 = _medparameter.MED_SEG3
MED_SEG4 = _medparameter.MED_SEG4
MED_TRIA3 = _medparameter.MED_TRIA3
MED_QUAD4 = _medparameter.MED_QUAD4
MED_TRIA6 = _medparameter.MED_TRIA6
MED_TRIA7 = _medparameter.MED_TRIA7
MED_QUAD8 = _medparameter.MED_QUAD8
MED_QUAD9 = _medparameter.MED_QUAD9
MED_TETRA4 = _medparameter.MED_TETRA4
MED_PYRA5 = _medparameter.MED_PYRA5
MED_PENTA6 = _medparameter.MED_PENTA6
MED_HEXA8 = _medparameter.MED_HEXA8
MED_TETRA10 = _medparameter.MED_TETRA10
MED_OCTA12 = _medparameter.MED_OCTA12
MED_PYRA13 = _medparameter.MED_PYRA13
MED_PENTA15 = _medparameter.MED_PENTA15
MED_PENTA18 = _medparameter.MED_PENTA18
MED_HEXA20 = _medparameter.MED_HEXA20
MED_HEXA27 = _medparameter.MED_HEXA27
MED_POLYGON = _medparameter.MED_POLYGON
MED_POLYGON2 = _medparameter.MED_POLYGON2
MED_POLYHEDRON = _medparameter.MED_POLYHEDRON
MED_STRUCT_GEO_INTERNAL = _medparameter.MED_STRUCT_GEO_INTERNAL
MED_STRUCT_GEO_SUP_INTERNAL = _medparameter.MED_STRUCT_GEO_SUP_INTERNAL
MED_NONE = _medparameter.MED_NONE
MED_NO_GEOTYPE = _medparameter.MED_NO_GEOTYPE
MED_UNDEF_GEOTYPE = _medparameter.MED_UNDEF_GEOTYPE
MED_UNDEF_GEOMETRY_TYPE = _medparameter.MED_UNDEF_GEOMETRY_TYPE
MED_ALL_GEOTYPE = _medparameter.MED_ALL_GEOTYPE
MED_GEO_ALL = _medparameter.MED_GEO_ALL
MED_N_CELL_GEO = _medparameter.MED_N_CELL_GEO
MED_N_CELL_FIXED_GEO = _medparameter.MED_N_CELL_FIXED_GEO
MED_N_CELL_GEO_FIXED_CON = _medparameter.MED_N_CELL_GEO_FIXED_CON
MED_N_FACE_GEO = _medparameter.MED_N_FACE_GEO
MED_N_FACE_FIXED_GEO = _medparameter.MED_N_FACE_FIXED_GEO
MED_N_FACE_GEO_FIXED_CON = _medparameter.MED_N_FACE_GEO_FIXED_CON
MED_N_EDGE_TYPES = _medparameter.MED_N_EDGE_TYPES
MED_N_EDGE_FIXED_GEO = _medparameter.MED_N_EDGE_FIXED_GEO
MED_N_EDGE_GEO_FIXED_CON = _medparameter.MED_N_EDGE_GEO_FIXED_CON
MED_N_NODE_GEO = _medparameter.MED_N_NODE_GEO
MED_N_NODE_FIXED_GEO = _medparameter.MED_N_NODE_FIXED_GEO
MED_N_NODE_GEO_FIXED_CON = _medparameter.MED_N_NODE_GEO_FIXED_CON
MED_NODAL = _medparameter.MED_NODAL
MED_DESCENDING = _medparameter.MED_DESCENDING
MED_UNDEF_CONNECTIVITY_MODE = _medparameter.MED_UNDEF_CONNECTIVITY_MODE
MED_NO_CMODE = _medparameter.MED_NO_CMODE
MED_CARTESIAN = _medparameter.MED_CARTESIAN
MED_CYLINDRICAL = _medparameter.MED_CYLINDRICAL
MED_SPHERICAL = _medparameter.MED_SPHERICAL
MED_UNDEF_AXIS_TYPE = _medparameter.MED_UNDEF_AXIS_TYPE
MED_FALSE = _medparameter.MED_FALSE
MED_TRUE = _medparameter.MED_TRUE
MED_GAUSS_ELNO = _medparameter.MED_GAUSS_ELNO
MED_IPOINT_ELNO = _medparameter.MED_IPOINT_ELNO
MED_NO_NAME = _medparameter.MED_NO_NAME
MED_NO_MESHNAME = _medparameter.MED_NO_MESHNAME
MED_NO_MESH = _medparameter.MED_NO_MESH
MED_NO_MESH_SUPPORT = _medparameter.MED_NO_MESH_SUPPORT
MED_NO_LOCALIZATION = _medparameter.MED_NO_LOCALIZATION
MED_NO_INTERPOLATION = _medparameter.MED_NO_INTERPOLATION
MED_NO_IPOINT_INTERNAL = _medparameter.MED_NO_IPOINT_INTERNAL
MED_NO_PROFILE = _medparameter.MED_NO_PROFILE
MED_NO_GROUP = _medparameter.MED_NO_GROUP
MED_ALLENTITIES_PROFILE = _medparameter.MED_ALLENTITIES_PROFILE
MED_NO_PROFILE_INTERNAL = _medparameter.MED_NO_PROFILE_INTERNAL
MED_SAME_PROFILE_INTERNAL = _medparameter.MED_SAME_PROFILE_INTERNAL
MED_ALL_CONSTITUENT = _medparameter.MED_ALL_CONSTITUENT
MED_UNDEF_SIZE = _medparameter.MED_UNDEF_SIZE
MED_NO_PROFILE_SIZE = _medparameter.MED_NO_PROFILE_SIZE
MED_SORT_DTIT = _medparameter.MED_SORT_DTIT
MED_SORT_ITDT = _medparameter.MED_SORT_ITDT
MED_SORT_UNDEF = _medparameter.MED_SORT_UNDEF
MED_NO_DT = _medparameter.MED_NO_DT
MED_NO_IT = _medparameter.MED_NO_IT
MED_UNDEF_DT = _medparameter.MED_UNDEF_DT
MED_ATT_NOT_FILLED = _medparameter.MED_ATT_NOT_FILLED
MED_MAX_FILTER_SPACES = _medparameter.MED_MAX_FILTER_SPACES
class med_filter(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, med_filter, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, med_filter, name)
    __repr__ = _swig_repr
    __swig_setmethods__["nspaces"] = _medparameter.med_filter_nspaces_set
    __swig_getmethods__["nspaces"] = _medparameter.med_filter_nspaces_get
    if _newclass:
        nspaces = _swig_property(_medparameter.med_filter_nspaces_get, _medparameter.med_filter_nspaces_set)
    __swig_setmethods__["memspace"] = _medparameter.med_filter_memspace_set
    __swig_getmethods__["memspace"] = _medparameter.med_filter_memspace_get
    if _newclass:
        memspace = _swig_property(_medparameter.med_filter_memspace_get, _medparameter.med_filter_memspace_set)
    __swig_setmethods__["diskspace"] = _medparameter.med_filter_diskspace_set
    __swig_getmethods__["diskspace"] = _medparameter.med_filter_diskspace_get
    if _newclass:
        diskspace = _swig_property(_medparameter.med_filter_diskspace_get, _medparameter.med_filter_diskspace_set)
    __swig_setmethods__["nentity"] = _medparameter.med_filter_nentity_set
    __swig_getmethods__["nentity"] = _medparameter.med_filter_nentity_get
    if _newclass:
        nentity = _swig_property(_medparameter.med_filter_nentity_get, _medparameter.med_filter_nentity_set)
    __swig_setmethods__["nvaluesperentity"] = _medparameter.med_filter_nvaluesperentity_set
    __swig_getmethods__["nvaluesperentity"] = _medparameter.med_filter_nvaluesperentity_get
    if _newclass:
        nvaluesperentity = _swig_property(_medparameter.med_filter_nvaluesperentity_get, _medparameter.med_filter_nvaluesperentity_set)
    __swig_setmethods__["nconstituentpervalue"] = _medparameter.med_filter_nconstituentpervalue_set
    __swig_getmethods__["nconstituentpervalue"] = _medparameter.med_filter_nconstituentpervalue_get
    if _newclass:
        nconstituentpervalue = _swig_property(_medparameter.med_filter_nconstituentpervalue_get, _medparameter.med_filter_nconstituentpervalue_set)
    __swig_setmethods__["constituentselect"] = _medparameter.med_filter_constituentselect_set
    __swig_getmethods__["constituentselect"] = _medparameter.med_filter_constituentselect_get
    if _newclass:
        constituentselect = _swig_property(_medparameter.med_filter_constituentselect_get, _medparameter.med_filter_constituentselect_set)
    __swig_setmethods__["switchmode"] = _medparameter.med_filter_switchmode_set
    __swig_getmethods__["switchmode"] = _medparameter.med_filter_switchmode_get
    if _newclass:
        switchmode = _swig_property(_medparameter.med_filter_switchmode_get, _medparameter.med_filter_switchmode_set)
    __swig_setmethods__["filterarraysize"] = _medparameter.med_filter_filterarraysize_set
    __swig_getmethods__["filterarraysize"] = _medparameter.med_filter_filterarraysize_get
    if _newclass:
        filterarraysize = _swig_property(_medparameter.med_filter_filterarraysize_get, _medparameter.med_filter_filterarraysize_set)
    __swig_setmethods__["filterarray23v30"] = _medparameter.med_filter_filterarray23v30_set
    __swig_getmethods__["filterarray23v30"] = _medparameter.med_filter_filterarray23v30_get
    if _newclass:
        filterarray23v30 = _swig_property(_medparameter.med_filter_filterarray23v30_get, _medparameter.med_filter_filterarray23v30_set)
    __swig_setmethods__["profilearraysize"] = _medparameter.med_filter_profilearraysize_set
    __swig_getmethods__["profilearraysize"] = _medparameter.med_filter_profilearraysize_get
    if _newclass:
        profilearraysize = _swig_property(_medparameter.med_filter_profilearraysize_get, _medparameter.med_filter_profilearraysize_set)
    __swig_setmethods__["storagemode"] = _medparameter.med_filter_storagemode_set
    __swig_getmethods__["storagemode"] = _medparameter.med_filter_storagemode_get
    if _newclass:
        storagemode = _swig_property(_medparameter.med_filter_storagemode_get, _medparameter.med_filter_storagemode_set)
    __swig_setmethods__["profilename"] = _medparameter.med_filter_profilename_set
    __swig_getmethods__["profilename"] = _medparameter.med_filter_profilename_get
    if _newclass:
        profilename = _swig_property(_medparameter.med_filter_profilename_get, _medparameter.med_filter_profilename_set)

    def __init__(self):
        """__init__(self) -> med_filter"""
        this = _medparameter.new_med_filter()
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this
    __swig_destroy__ = _medparameter.delete_med_filter
    __del__ = lambda self: None
med_filter_swigregister = _medparameter.med_filter_swigregister
med_filter_swigregister(med_filter)

MED_NO_FILTER_SIZE = _medparameter.MED_NO_FILTER_SIZE
MED_NO_PROFILE_F = _medparameter.MED_NO_PROFILE_F
class med_file_version(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, med_file_version, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, med_file_version, name)
    __repr__ = _swig_repr
    __swig_setmethods__["majeur"] = _medparameter.med_file_version_majeur_set
    __swig_getmethods__["majeur"] = _medparameter.med_file_version_majeur_get
    if _newclass:
        majeur = _swig_property(_medparameter.med_file_version_majeur_get, _medparameter.med_file_version_majeur_set)
    __swig_setmethods__["mineur"] = _medparameter.med_file_version_mineur_set
    __swig_getmethods__["mineur"] = _medparameter.med_file_version_mineur_get
    if _newclass:
        mineur = _swig_property(_medparameter.med_file_version_mineur_get, _medparameter.med_file_version_mineur_set)
    __swig_setmethods__["release"] = _medparameter.med_file_version_release_set
    __swig_getmethods__["release"] = _medparameter.med_file_version_release_get
    if _newclass:
        release = _swig_property(_medparameter.med_file_version_release_get, _medparameter.med_file_version_release_set)

    def __init__(self):
        """__init__(self) -> med_file_version"""
        this = _medparameter.new_med_file_version()
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this
    __swig_destroy__ = _medparameter.delete_med_file_version
    __del__ = lambda self: None
med_file_version_swigregister = _medparameter.med_file_version_swigregister
med_file_version_swigregister(med_file_version)

class med_memfile(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, med_memfile, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, med_memfile, name)
    __repr__ = _swig_repr
    __swig_setmethods__["app_image_ptr"] = _medparameter.med_memfile_app_image_ptr_set
    __swig_getmethods__["app_image_ptr"] = _medparameter.med_memfile_app_image_ptr_get
    if _newclass:
        app_image_ptr = _swig_property(_medparameter.med_memfile_app_image_ptr_get, _medparameter.med_memfile_app_image_ptr_set)
    __swig_setmethods__["app_image_size"] = _medparameter.med_memfile_app_image_size_set
    __swig_getmethods__["app_image_size"] = _medparameter.med_memfile_app_image_size_get
    if _newclass:
        app_image_size = _swig_property(_medparameter.med_memfile_app_image_size_get, _medparameter.med_memfile_app_image_size_set)
    __swig_setmethods__["ref_count"] = _medparameter.med_memfile_ref_count_set
    __swig_getmethods__["ref_count"] = _medparameter.med_memfile_ref_count_get
    if _newclass:
        ref_count = _swig_property(_medparameter.med_memfile_ref_count_get, _medparameter.med_memfile_ref_count_set)
    __swig_setmethods__["fapl_image_ptr"] = _medparameter.med_memfile_fapl_image_ptr_set
    __swig_getmethods__["fapl_image_ptr"] = _medparameter.med_memfile_fapl_image_ptr_get
    if _newclass:
        fapl_image_ptr = _swig_property(_medparameter.med_memfile_fapl_image_ptr_get, _medparameter.med_memfile_fapl_image_ptr_set)
    __swig_setmethods__["fapl_image_size"] = _medparameter.med_memfile_fapl_image_size_set
    __swig_getmethods__["fapl_image_size"] = _medparameter.med_memfile_fapl_image_size_get
    if _newclass:
        fapl_image_size = _swig_property(_medparameter.med_memfile_fapl_image_size_get, _medparameter.med_memfile_fapl_image_size_set)
    __swig_setmethods__["fapl_ref_count"] = _medparameter.med_memfile_fapl_ref_count_set
    __swig_getmethods__["fapl_ref_count"] = _medparameter.med_memfile_fapl_ref_count_get
    if _newclass:
        fapl_ref_count = _swig_property(_medparameter.med_memfile_fapl_ref_count_get, _medparameter.med_memfile_fapl_ref_count_set)
    __swig_setmethods__["vfd_image_ptr"] = _medparameter.med_memfile_vfd_image_ptr_set
    __swig_getmethods__["vfd_image_ptr"] = _medparameter.med_memfile_vfd_image_ptr_get
    if _newclass:
        vfd_image_ptr = _swig_property(_medparameter.med_memfile_vfd_image_ptr_get, _medparameter.med_memfile_vfd_image_ptr_set)
    __swig_setmethods__["vfd_image_size"] = _medparameter.med_memfile_vfd_image_size_set
    __swig_getmethods__["vfd_image_size"] = _medparameter.med_memfile_vfd_image_size_get
    if _newclass:
        vfd_image_size = _swig_property(_medparameter.med_memfile_vfd_image_size_get, _medparameter.med_memfile_vfd_image_size_set)
    __swig_setmethods__["vfd_ref_count"] = _medparameter.med_memfile_vfd_ref_count_set
    __swig_getmethods__["vfd_ref_count"] = _medparameter.med_memfile_vfd_ref_count_get
    if _newclass:
        vfd_ref_count = _swig_property(_medparameter.med_memfile_vfd_ref_count_get, _medparameter.med_memfile_vfd_ref_count_set)
    __swig_setmethods__["flags"] = _medparameter.med_memfile_flags_set
    __swig_getmethods__["flags"] = _medparameter.med_memfile_flags_get
    if _newclass:
        flags = _swig_property(_medparameter.med_memfile_flags_get, _medparameter.med_memfile_flags_set)

    def __init__(self):
        """__init__(self) -> med_memfile"""
        this = _medparameter.new_med_memfile()
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this
    __swig_destroy__ = _medparameter.delete_med_memfile
    __del__ = lambda self: None
med_memfile_swigregister = _medparameter.med_memfile_swigregister
med_memfile_swigregister(med_memfile)

MED_PARTICLE_NAME = _medparameter.MED_PARTICLE_NAME
MED_BALL_NAME = _medparameter.MED_BALL_NAME
MED_BEAM_NAME = _medparameter.MED_BEAM_NAME
MED_PARTICLE_LABEL = _medparameter.MED_PARTICLE_LABEL
MED_BALL_DIAMETER = _medparameter.MED_BALL_DIAMETER
MED_BEAM_THICKNESS = _medparameter.MED_BEAM_THICKNESS
import med.medenum
class MEDBOOL(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, MEDBOOL, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, MEDBOOL, name)
    __repr__ = _swig_repr

    def iterator(self):
        return _medparameter.MEDBOOL_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medparameter.MEDBOOL___nonzero__(self)

    def __bool__(self):
        return _medparameter.MEDBOOL___bool__(self)

    def __len__(self):
        return _medparameter.MEDBOOL___len__(self)

    def __getslice__(self, i, j):
        return _medparameter.MEDBOOL___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medparameter.MEDBOOL___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medparameter.MEDBOOL___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medparameter.MEDBOOL___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medparameter.MEDBOOL___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medparameter.MEDBOOL___setitem__(self, *args)

    def pop(self):
        return _medparameter.MEDBOOL_pop(self)

    def append(self, x):
        return _medparameter.MEDBOOL_append(self, x)

    def empty(self):
        return _medparameter.MEDBOOL_empty(self)

    def size(self):
        return _medparameter.MEDBOOL_size(self)

    def swap(self, v):
        return _medparameter.MEDBOOL_swap(self, v)

    def begin(self):
        return _medparameter.MEDBOOL_begin(self)

    def end(self):
        return _medparameter.MEDBOOL_end(self)

    def rbegin(self):
        return _medparameter.MEDBOOL_rbegin(self)

    def rend(self):
        return _medparameter.MEDBOOL_rend(self)

    def clear(self):
        return _medparameter.MEDBOOL_clear(self)

    def get_allocator(self):
        return _medparameter.MEDBOOL_get_allocator(self)

    def pop_back(self):
        return _medparameter.MEDBOOL_pop_back(self)

    def erase(self, *args):
        return _medparameter.MEDBOOL_erase(self, *args)

    def __init__(self, *args):
        this = _medparameter.new_MEDBOOL(*args)
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this

    def push_back(self, x):
        return _medparameter.MEDBOOL_push_back(self, x)

    def front(self):
        return _medparameter.MEDBOOL_front(self)

    def back(self):
        return _medparameter.MEDBOOL_back(self)

    def assign(self, n, x):
        return _medparameter.MEDBOOL_assign(self, n, x)

    def resize(self, *args):
        return _medparameter.MEDBOOL_resize(self, *args)

    def insert(self, *args):
        return _medparameter.MEDBOOL_insert(self, *args)

    def reserve(self, n):
        return _medparameter.MEDBOOL_reserve(self, n)

    def capacity(self):
        return _medparameter.MEDBOOL_capacity(self)
    __swig_destroy__ = _medparameter.delete_MEDBOOL
    __del__ = lambda self: None
MEDBOOL_swigregister = _medparameter.MEDBOOL_swigregister
MEDBOOL_swigregister(MEDBOOL)
cvar = _medparameter.cvar
MED_GET_ENTITY_TYPENAME = cvar.MED_GET_ENTITY_TYPENAME
MED_GET_CELL_GEOMETRY_TYPENAME = cvar.MED_GET_CELL_GEOMETRY_TYPENAME
MED_GET_FACE_GEOMETRY_TYPENAME = cvar.MED_GET_FACE_GEOMETRY_TYPENAME


MEDBOOL.__str__= lambda self: str([x for x in self])
MEDBOOL.__repr__= lambda self: "MEDBOOL("+str([x for x in self])+")"

class MEDFLOAT(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, MEDFLOAT, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, MEDFLOAT, name)
    __repr__ = _swig_repr

    def iterator(self):
        return _medparameter.MEDFLOAT_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medparameter.MEDFLOAT___nonzero__(self)

    def __bool__(self):
        return _medparameter.MEDFLOAT___bool__(self)

    def __len__(self):
        return _medparameter.MEDFLOAT___len__(self)

    def __getslice__(self, i, j):
        return _medparameter.MEDFLOAT___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medparameter.MEDFLOAT___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medparameter.MEDFLOAT___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medparameter.MEDFLOAT___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medparameter.MEDFLOAT___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medparameter.MEDFLOAT___setitem__(self, *args)

    def pop(self):
        return _medparameter.MEDFLOAT_pop(self)

    def append(self, x):
        return _medparameter.MEDFLOAT_append(self, x)

    def empty(self):
        return _medparameter.MEDFLOAT_empty(self)

    def size(self):
        return _medparameter.MEDFLOAT_size(self)

    def swap(self, v):
        return _medparameter.MEDFLOAT_swap(self, v)

    def begin(self):
        return _medparameter.MEDFLOAT_begin(self)

    def end(self):
        return _medparameter.MEDFLOAT_end(self)

    def rbegin(self):
        return _medparameter.MEDFLOAT_rbegin(self)

    def rend(self):
        return _medparameter.MEDFLOAT_rend(self)

    def clear(self):
        return _medparameter.MEDFLOAT_clear(self)

    def get_allocator(self):
        return _medparameter.MEDFLOAT_get_allocator(self)

    def pop_back(self):
        return _medparameter.MEDFLOAT_pop_back(self)

    def erase(self, *args):
        return _medparameter.MEDFLOAT_erase(self, *args)

    def __init__(self, *args):
        this = _medparameter.new_MEDFLOAT(*args)
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this

    def push_back(self, x):
        return _medparameter.MEDFLOAT_push_back(self, x)

    def front(self):
        return _medparameter.MEDFLOAT_front(self)

    def back(self):
        return _medparameter.MEDFLOAT_back(self)

    def assign(self, n, x):
        return _medparameter.MEDFLOAT_assign(self, n, x)

    def resize(self, *args):
        return _medparameter.MEDFLOAT_resize(self, *args)

    def insert(self, *args):
        return _medparameter.MEDFLOAT_insert(self, *args)

    def reserve(self, n):
        return _medparameter.MEDFLOAT_reserve(self, n)

    def capacity(self):
        return _medparameter.MEDFLOAT_capacity(self)

    def __iadd__(self, value):
        return _medparameter.MEDFLOAT___iadd__(self, value)

    def __add__(self, value):
        return _medparameter.MEDFLOAT___add__(self, value)

    def __isub__(self, value):
        return _medparameter.MEDFLOAT___isub__(self, value)

    def __sub__(self, value):
        return _medparameter.MEDFLOAT___sub__(self, value)

    def __imul__(self, value):
        return _medparameter.MEDFLOAT___imul__(self, value)

    def __mul__(self, value):
        return _medparameter.MEDFLOAT___mul__(self, value)

    def __itruediv__(self, *args):
        return _medparameter.MEDFLOAT___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medparameter.MEDFLOAT___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value):
        return _medparameter.MEDFLOAT___le__(self, value)

    def __lt__(self, value):
        return _medparameter.MEDFLOAT___lt__(self, value)

    def __gt__(self, value):
        return _medparameter.MEDFLOAT___gt__(self, value)

    def __ge__(self, value):
        return _medparameter.MEDFLOAT___ge__(self, value)

    def __eq__(self, value):
        return _medparameter.MEDFLOAT___eq__(self, value)

    def __ne__(self, value):
        return _medparameter.MEDFLOAT___ne__(self, value)
    __swig_destroy__ = _medparameter.delete_MEDFLOAT
    __del__ = lambda self: None
MEDFLOAT_swigregister = _medparameter.MEDFLOAT_swigregister
MEDFLOAT_swigregister(MEDFLOAT)


MEDFLOAT.__str__= lambda self: str([x for x in self])
MEDFLOAT.__repr__= lambda self:"MEDFLOAT" +"("+str([x for x in self])+")"


MEDFLOAT64=MEDFLOAT
MEDDOUBLE=MEDFLOAT

class MEDFLOAT32(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, MEDFLOAT32, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, MEDFLOAT32, name)
    __repr__ = _swig_repr

    def iterator(self):
        return _medparameter.MEDFLOAT32_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medparameter.MEDFLOAT32___nonzero__(self)

    def __bool__(self):
        return _medparameter.MEDFLOAT32___bool__(self)

    def __len__(self):
        return _medparameter.MEDFLOAT32___len__(self)

    def __getslice__(self, i, j):
        return _medparameter.MEDFLOAT32___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medparameter.MEDFLOAT32___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medparameter.MEDFLOAT32___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medparameter.MEDFLOAT32___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medparameter.MEDFLOAT32___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medparameter.MEDFLOAT32___setitem__(self, *args)

    def pop(self):
        return _medparameter.MEDFLOAT32_pop(self)

    def append(self, x):
        return _medparameter.MEDFLOAT32_append(self, x)

    def empty(self):
        return _medparameter.MEDFLOAT32_empty(self)

    def size(self):
        return _medparameter.MEDFLOAT32_size(self)

    def swap(self, v):
        return _medparameter.MEDFLOAT32_swap(self, v)

    def begin(self):
        return _medparameter.MEDFLOAT32_begin(self)

    def end(self):
        return _medparameter.MEDFLOAT32_end(self)

    def rbegin(self):
        return _medparameter.MEDFLOAT32_rbegin(self)

    def rend(self):
        return _medparameter.MEDFLOAT32_rend(self)

    def clear(self):
        return _medparameter.MEDFLOAT32_clear(self)

    def get_allocator(self):
        return _medparameter.MEDFLOAT32_get_allocator(self)

    def pop_back(self):
        return _medparameter.MEDFLOAT32_pop_back(self)

    def erase(self, *args):
        return _medparameter.MEDFLOAT32_erase(self, *args)

    def __init__(self, *args):
        this = _medparameter.new_MEDFLOAT32(*args)
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this

    def push_back(self, x):
        return _medparameter.MEDFLOAT32_push_back(self, x)

    def front(self):
        return _medparameter.MEDFLOAT32_front(self)

    def back(self):
        return _medparameter.MEDFLOAT32_back(self)

    def assign(self, n, x):
        return _medparameter.MEDFLOAT32_assign(self, n, x)

    def resize(self, *args):
        return _medparameter.MEDFLOAT32_resize(self, *args)

    def insert(self, *args):
        return _medparameter.MEDFLOAT32_insert(self, *args)

    def reserve(self, n):
        return _medparameter.MEDFLOAT32_reserve(self, n)

    def capacity(self):
        return _medparameter.MEDFLOAT32_capacity(self)

    def __iadd__(self, value):
        return _medparameter.MEDFLOAT32___iadd__(self, value)

    def __add__(self, value):
        return _medparameter.MEDFLOAT32___add__(self, value)

    def __isub__(self, value):
        return _medparameter.MEDFLOAT32___isub__(self, value)

    def __sub__(self, value):
        return _medparameter.MEDFLOAT32___sub__(self, value)

    def __imul__(self, value):
        return _medparameter.MEDFLOAT32___imul__(self, value)

    def __mul__(self, value):
        return _medparameter.MEDFLOAT32___mul__(self, value)

    def __itruediv__(self, *args):
        return _medparameter.MEDFLOAT32___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medparameter.MEDFLOAT32___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value):
        return _medparameter.MEDFLOAT32___le__(self, value)

    def __lt__(self, value):
        return _medparameter.MEDFLOAT32___lt__(self, value)

    def __gt__(self, value):
        return _medparameter.MEDFLOAT32___gt__(self, value)

    def __ge__(self, value):
        return _medparameter.MEDFLOAT32___ge__(self, value)

    def __eq__(self, value):
        return _medparameter.MEDFLOAT32___eq__(self, value)

    def __ne__(self, value):
        return _medparameter.MEDFLOAT32___ne__(self, value)
    __swig_destroy__ = _medparameter.delete_MEDFLOAT32
    __del__ = lambda self: None
MEDFLOAT32_swigregister = _medparameter.MEDFLOAT32_swigregister
MEDFLOAT32_swigregister(MEDFLOAT32)


MEDFLOAT32.__str__= lambda self: str([x for x in self])
MEDFLOAT32.__repr__= lambda self:"MEDFLOAT32" +"("+str([x for x in self])+")"

class MEDINT(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, MEDINT, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, MEDINT, name)
    __repr__ = _swig_repr

    def iterator(self):
        return _medparameter.MEDINT_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medparameter.MEDINT___nonzero__(self)

    def __bool__(self):
        return _medparameter.MEDINT___bool__(self)

    def __len__(self):
        return _medparameter.MEDINT___len__(self)

    def __getslice__(self, i, j):
        return _medparameter.MEDINT___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medparameter.MEDINT___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medparameter.MEDINT___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medparameter.MEDINT___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medparameter.MEDINT___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medparameter.MEDINT___setitem__(self, *args)

    def pop(self):
        return _medparameter.MEDINT_pop(self)

    def append(self, x):
        return _medparameter.MEDINT_append(self, x)

    def empty(self):
        return _medparameter.MEDINT_empty(self)

    def size(self):
        return _medparameter.MEDINT_size(self)

    def swap(self, v):
        return _medparameter.MEDINT_swap(self, v)

    def begin(self):
        return _medparameter.MEDINT_begin(self)

    def end(self):
        return _medparameter.MEDINT_end(self)

    def rbegin(self):
        return _medparameter.MEDINT_rbegin(self)

    def rend(self):
        return _medparameter.MEDINT_rend(self)

    def clear(self):
        return _medparameter.MEDINT_clear(self)

    def get_allocator(self):
        return _medparameter.MEDINT_get_allocator(self)

    def pop_back(self):
        return _medparameter.MEDINT_pop_back(self)

    def erase(self, *args):
        return _medparameter.MEDINT_erase(self, *args)

    def __init__(self, *args):
        this = _medparameter.new_MEDINT(*args)
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this

    def push_back(self, x):
        return _medparameter.MEDINT_push_back(self, x)

    def front(self):
        return _medparameter.MEDINT_front(self)

    def back(self):
        return _medparameter.MEDINT_back(self)

    def assign(self, n, x):
        return _medparameter.MEDINT_assign(self, n, x)

    def resize(self, *args):
        return _medparameter.MEDINT_resize(self, *args)

    def insert(self, *args):
        return _medparameter.MEDINT_insert(self, *args)

    def reserve(self, n):
        return _medparameter.MEDINT_reserve(self, n)

    def capacity(self):
        return _medparameter.MEDINT_capacity(self)

    def __iadd__(self, value):
        return _medparameter.MEDINT___iadd__(self, value)

    def __add__(self, value):
        return _medparameter.MEDINT___add__(self, value)

    def __isub__(self, value):
        return _medparameter.MEDINT___isub__(self, value)

    def __sub__(self, value):
        return _medparameter.MEDINT___sub__(self, value)

    def __imul__(self, value):
        return _medparameter.MEDINT___imul__(self, value)

    def __mul__(self, value):
        return _medparameter.MEDINT___mul__(self, value)

    def __itruediv__(self, *args):
        return _medparameter.MEDINT___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medparameter.MEDINT___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value):
        return _medparameter.MEDINT___le__(self, value)

    def __lt__(self, value):
        return _medparameter.MEDINT___lt__(self, value)

    def __gt__(self, value):
        return _medparameter.MEDINT___gt__(self, value)

    def __ge__(self, value):
        return _medparameter.MEDINT___ge__(self, value)

    def __eq__(self, value):
        return _medparameter.MEDINT___eq__(self, value)

    def __ne__(self, value):
        return _medparameter.MEDINT___ne__(self, value)
    __swig_destroy__ = _medparameter.delete_MEDINT
    __del__ = lambda self: None
MEDINT_swigregister = _medparameter.MEDINT_swigregister
MEDINT_swigregister(MEDINT)


MEDINT.__str__= lambda self: str([x for x in self])
MEDINT.__repr__= lambda self:"MEDINT" +"("+str([x for x in self])+")"


MEDINT64=MEDINT

class MEDINT32(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, MEDINT32, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, MEDINT32, name)
    __repr__ = _swig_repr

    def iterator(self):
        return _medparameter.MEDINT32_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medparameter.MEDINT32___nonzero__(self)

    def __bool__(self):
        return _medparameter.MEDINT32___bool__(self)

    def __len__(self):
        return _medparameter.MEDINT32___len__(self)

    def __getslice__(self, i, j):
        return _medparameter.MEDINT32___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medparameter.MEDINT32___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medparameter.MEDINT32___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medparameter.MEDINT32___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medparameter.MEDINT32___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medparameter.MEDINT32___setitem__(self, *args)

    def pop(self):
        return _medparameter.MEDINT32_pop(self)

    def append(self, x):
        return _medparameter.MEDINT32_append(self, x)

    def empty(self):
        return _medparameter.MEDINT32_empty(self)

    def size(self):
        return _medparameter.MEDINT32_size(self)

    def swap(self, v):
        return _medparameter.MEDINT32_swap(self, v)

    def begin(self):
        return _medparameter.MEDINT32_begin(self)

    def end(self):
        return _medparameter.MEDINT32_end(self)

    def rbegin(self):
        return _medparameter.MEDINT32_rbegin(self)

    def rend(self):
        return _medparameter.MEDINT32_rend(self)

    def clear(self):
        return _medparameter.MEDINT32_clear(self)

    def get_allocator(self):
        return _medparameter.MEDINT32_get_allocator(self)

    def pop_back(self):
        return _medparameter.MEDINT32_pop_back(self)

    def erase(self, *args):
        return _medparameter.MEDINT32_erase(self, *args)

    def __init__(self, *args):
        this = _medparameter.new_MEDINT32(*args)
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this

    def push_back(self, x):
        return _medparameter.MEDINT32_push_back(self, x)

    def front(self):
        return _medparameter.MEDINT32_front(self)

    def back(self):
        return _medparameter.MEDINT32_back(self)

    def assign(self, n, x):
        return _medparameter.MEDINT32_assign(self, n, x)

    def resize(self, *args):
        return _medparameter.MEDINT32_resize(self, *args)

    def insert(self, *args):
        return _medparameter.MEDINT32_insert(self, *args)

    def reserve(self, n):
        return _medparameter.MEDINT32_reserve(self, n)

    def capacity(self):
        return _medparameter.MEDINT32_capacity(self)

    def __iadd__(self, value):
        return _medparameter.MEDINT32___iadd__(self, value)

    def __add__(self, value):
        return _medparameter.MEDINT32___add__(self, value)

    def __isub__(self, value):
        return _medparameter.MEDINT32___isub__(self, value)

    def __sub__(self, value):
        return _medparameter.MEDINT32___sub__(self, value)

    def __imul__(self, value):
        return _medparameter.MEDINT32___imul__(self, value)

    def __mul__(self, value):
        return _medparameter.MEDINT32___mul__(self, value)

    def __itruediv__(self, *args):
        return _medparameter.MEDINT32___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medparameter.MEDINT32___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value):
        return _medparameter.MEDINT32___le__(self, value)

    def __lt__(self, value):
        return _medparameter.MEDINT32___lt__(self, value)

    def __gt__(self, value):
        return _medparameter.MEDINT32___gt__(self, value)

    def __ge__(self, value):
        return _medparameter.MEDINT32___ge__(self, value)

    def __eq__(self, value):
        return _medparameter.MEDINT32___eq__(self, value)

    def __ne__(self, value):
        return _medparameter.MEDINT32___ne__(self, value)
    __swig_destroy__ = _medparameter.delete_MEDINT32
    __del__ = lambda self: None
MEDINT32_swigregister = _medparameter.MEDINT32_swigregister
MEDINT32_swigregister(MEDINT32)


MEDINT32.__str__= lambda self: str([x for x in self])
MEDINT32.__repr__= lambda self:"MEDINT32" +"("+str([x for x in self])+")"

class MEDCHAR(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, MEDCHAR, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, MEDCHAR, name)
    __repr__ = _swig_repr

    def iterator(self):
        return _medparameter.MEDCHAR_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medparameter.MEDCHAR___nonzero__(self)

    def __bool__(self):
        return _medparameter.MEDCHAR___bool__(self)

    def __len__(self):
        return _medparameter.MEDCHAR___len__(self)

    def __getslice__(self, i, j):
        return _medparameter.MEDCHAR___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medparameter.MEDCHAR___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medparameter.MEDCHAR___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medparameter.MEDCHAR___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medparameter.MEDCHAR___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medparameter.MEDCHAR___setitem__(self, *args)

    def pop(self):
        return _medparameter.MEDCHAR_pop(self)

    def append(self, x):
        return _medparameter.MEDCHAR_append(self, x)

    def empty(self):
        return _medparameter.MEDCHAR_empty(self)

    def size(self):
        return _medparameter.MEDCHAR_size(self)

    def swap(self, v):
        return _medparameter.MEDCHAR_swap(self, v)

    def begin(self):
        return _medparameter.MEDCHAR_begin(self)

    def end(self):
        return _medparameter.MEDCHAR_end(self)

    def rbegin(self):
        return _medparameter.MEDCHAR_rbegin(self)

    def rend(self):
        return _medparameter.MEDCHAR_rend(self)

    def clear(self):
        return _medparameter.MEDCHAR_clear(self)

    def get_allocator(self):
        return _medparameter.MEDCHAR_get_allocator(self)

    def pop_back(self):
        return _medparameter.MEDCHAR_pop_back(self)

    def erase(self, *args):
        return _medparameter.MEDCHAR_erase(self, *args)

    def __init__(self, *args):
        this = _medparameter.new_MEDCHAR(*args)
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this

    def push_back(self, x):
        return _medparameter.MEDCHAR_push_back(self, x)

    def front(self):
        return _medparameter.MEDCHAR_front(self)

    def back(self):
        return _medparameter.MEDCHAR_back(self)

    def assign(self, n, x):
        return _medparameter.MEDCHAR_assign(self, n, x)

    def resize(self, *args):
        return _medparameter.MEDCHAR_resize(self, *args)

    def insert(self, *args):
        return _medparameter.MEDCHAR_insert(self, *args)

    def reserve(self, n):
        return _medparameter.MEDCHAR_reserve(self, n)

    def capacity(self):
        return _medparameter.MEDCHAR_capacity(self)

    def __iadd__(self, value):
        return _medparameter.MEDCHAR___iadd__(self, value)

    def __add__(self, value):
        return _medparameter.MEDCHAR___add__(self, value)

    def __isub__(self, value):
        return _medparameter.MEDCHAR___isub__(self, value)

    def __sub__(self, value):
        return _medparameter.MEDCHAR___sub__(self, value)

    def __imul__(self, value):
        return _medparameter.MEDCHAR___imul__(self, value)

    def __mul__(self, value):
        return _medparameter.MEDCHAR___mul__(self, value)

    def __itruediv__(self, *args):
        return _medparameter.MEDCHAR___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medparameter.MEDCHAR___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value):
        return _medparameter.MEDCHAR___le__(self, value)

    def __lt__(self, value):
        return _medparameter.MEDCHAR___lt__(self, value)

    def __gt__(self, value):
        return _medparameter.MEDCHAR___gt__(self, value)

    def __ge__(self, value):
        return _medparameter.MEDCHAR___ge__(self, value)

    def __eq__(self, value):
        return _medparameter.MEDCHAR___eq__(self, value)

    def __ne__(self, value):
        return _medparameter.MEDCHAR___ne__(self, value)
    __swig_destroy__ = _medparameter.delete_MEDCHAR
    __del__ = lambda self: None
MEDCHAR_swigregister = _medparameter.MEDCHAR_swigregister
MEDCHAR_swigregister(MEDCHAR)


MEDCHAR.__str__= lambda self: str([x for x in self])
MEDCHAR.__repr__= lambda self:"MEDCHAR" +"("+str([x for x in self])+")"


MEDCHAR.__str__= lambda self: str([x for x in self])
MEDCHAR.__repr__= lambda self:"MEDCHAR" +"("+str([x for x in self])+")"


MEDCHAR.__str__= lambda self: str([x for x in self])
MEDCHAR.__repr__= lambda self:"MEDCHAR" +"("+str([x for x in self])+")"


def MEDparameterCr(fid, paramname, paramtype, description, dtunit):
    """
    MEDparameterCr(fid, paramname, paramtype, description, dtunit) -> med_err

    Parameters
    ----------
    fid: med_idt const
    paramname: char const *const
    paramtype: enum med_parameter_type const
    description: char const *const
    dtunit: char const *const

    """
    return _medparameter.MEDparameterCr(fid, paramname, paramtype, description, dtunit)

def MEDnParameter(fid):
    """
    MEDnParameter(fid) -> med_int

    Parameters
    ----------
    fid: med_idt const

    """
    return _medparameter.MEDnParameter(fid)

def MEDparameterInfo(fid, paramit):
    """
    MEDparameterInfo(fid, paramit) -> med_err

    Parameters
    ----------
    fid: med_idt const
    paramit: int const

    """
    return _medparameter.MEDparameterInfo(fid, paramit)

def MEDparameterInfoByName(fid, paramname):
    """
    MEDparameterInfoByName(fid, paramname) -> med_err

    Parameters
    ----------
    fid: med_idt const
    paramname: char const *const

    """
    return _medparameter.MEDparameterInfoByName(fid, paramname)

def MEDparameterValueWr(fid, paramname, numdt, numit, dt, value):
    """
    MEDparameterValueWr(fid, paramname, numdt, numit, dt, value) -> med_err

    Parameters
    ----------
    fid: med_idt const
    paramname: char const *const
    numdt: med_int const
    numit: med_int const
    dt: med_float const
    value: unsigned char const *const

    """
    return _medparameter.MEDparameterValueWr(fid, paramname, numdt, numit, dt, value)

def MEDparameterValueRd(fid, paramname, numdt, numit, value):
    """
    MEDparameterValueRd(fid, paramname, numdt, numit, value) -> med_err

    Parameters
    ----------
    fid: med_idt const
    paramname: char const *const
    numdt: med_int const
    numit: med_int const
    value: unsigned char *const

    """
    return _medparameter.MEDparameterValueRd(fid, paramname, numdt, numit, value)

def MEDparameterComputationStepInfo(fid, paramname, csit):
    """
    MEDparameterComputationStepInfo(fid, paramname, csit) -> med_err

    Parameters
    ----------
    fid: med_idt const
    paramname: char const *const
    csit: int const

    """
    return _medparameter.MEDparameterComputationStepInfo(fid, paramname, csit)
# This file is compatible with both classic and new-style classes.


